==> qtjambi-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiGui/QAccessibleSelectionInterface_shell.h <==
#ifndef QACCESSIBLESELECTIONINTERFACE_IMPL_SHELL_H
#define QACCESSIBLESELECTIONINTERFACE_IMPL_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtGui/qaccessible.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtJambi/RegistryAPI>


class QAccessibleSelectionInterface_shell : public QAccessibleSelectionInterface, public QtJambiShellInterface
{
public:
    QAccessibleSelectionInterface_shell();
    ~QAccessibleSelectionInterface_shell() override;

    bool clear() override;
    bool isSelected(QAccessibleInterface* childItem0) const override;
    bool select(QAccessibleInterface* childItem0) override;
    bool selectAll() override;
    QAccessibleInterface* selectedItem(int selectionIndex0) const override;
    int selectedItemCount() const override;
    QList<QAccessibleInterface*> selectedItems() const override;
    bool unselect(QAccessibleInterface* childItem0) override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAccessibleSelectionInterface_access : public QAccessibleSelectionInterface
{
    jboolean __qt_clear(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jboolean __qt_isSelected_QAccessibleInterface_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID childItem0) const;
    jboolean __qt_select_QAccessibleInterface_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID childItem0);
    jboolean __qt_selectAll(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_selectedItem_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint selectionIndex0) const;
    jint __qt_selectedItemCount(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_selectedItems(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_unselect_QAccessibleInterface_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID childItem0);
};

#endif // QACCESSIBLESELECTIONINTERFACE_IMPL_SHELL_H

==> qtjambi-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiGui/QAccessibleSelectionInterface_shell.h <==
#ifndef QACCESSIBLESELECTIONINTERFACE_IMPL_SHELL_H
#define QACCESSIBLESELECTIONINTERFACE_IMPL_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtGui/qaccessible.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtJambi/RegistryAPI>


class QAccessibleSelectionInterface_shell : public QAccessibleSelectionInterface, public QtJambiShellInterface
{
public:
    QAccessibleSelectionInterface_shell();
    ~QAccessibleSelectionInterface_shell() override;

    bool clear() override;
    bool isSelected(QAccessibleInterface* childItem0) const override;
    bool select(QAccessibleInterface* childItem0) override;
    bool selectAll() override;
    QAccessibleInterface* selectedItem(int selectionIndex0) const override;
    int selectedItemCount() const override;
    QList<QAccessibleInterface*> selectedItems() const override;
    bool unselect(QAccessibleInterface* childItem0) override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAccessibleSelectionInterface_access : public QAccessibleSelectionInterface
{
    jboolean __qt_clear(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jboolean __qt_isSelected_QAccessibleInterface_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID childItem0) const;
    jboolean __qt_select_QAccessibleInterface_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID childItem0);
    jboolean __qt_selectAll(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_selectedItem_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint selectionIndex0) const;
    jint __qt_selectedItemCount_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_selectedItems_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_unselect_QAccessibleInterface_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID childItem0);
};

#endif // QACCESSIBLESELECTIONINTERFACE_IMPL_SHELL_H
